@@ -2,9 +2,9 @@ use strict;
 use warnings;
 
 package Pod::Weaver::PluginBundle::DAGOLDEN;
-our $VERSION = '0.056'; # VERSION
+our $VERSION = '0.057'; # VERSION
 
-use Pod::Weaver 3.101635; # fixed ABSTRACT scanning
+use Pod::Weaver 4; # he played knick-knack on my door
 use Pod::Weaver::Config::Assembler;
 
 # Dependencies
@@ -30,11 +30,11 @@ END
 sub mvp_bundle_config {
     my @plugins;
     push @plugins, (
-        [ '@DAGOLDEN/Encoding', _exp('-Encoding'), {} ],
-        [ '@DAGOLDEN/WikiDoc',  _exp('-WikiDoc'),  {} ],
-        [ '@DAGOLDEN/CorePrep', _exp('@CorePrep'), {} ],
-        [ '@DAGOLDEN/Name',     _exp('Name'),      {} ],
-        [ '@DAGOLDEN/Version',  _exp('Version'),   {} ],
+        [ '@DAGOLDEN/SingleEncoding', _exp('-SingleEncoding'), {} ],
+        [ '@DAGOLDEN/WikiDoc',        _exp('-WikiDoc'),        {} ],
+        [ '@DAGOLDEN/CorePrep',       _exp('@CorePrep'),       {} ],
+        [ '@DAGOLDEN/Name',           _exp('Name'),            {} ],
+        [ '@DAGOLDEN/Version',        _exp('Version'),         {} ],
 
         [ '@DAGOLDEN/Prelude',     _exp('Region'),  { region_name => 'prelude' } ],
         [ '@DAGOLDEN/Synopsis',    _exp('Generic'), { header      => 'SYNOPSIS' } ],
@@ -98,7 +98,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -106,7 +106,7 @@ Pod::Weaver::PluginBundle::DAGOLDEN - DAGOLDEN's default Pod::Weaver config
 
 =head1 VERSION
 
-version 0.056
+version 0.057
 
 =head1 DESCRIPTION
 
